@@ -9,9 +9,9 @@ use Fcntl;
 use File::MoreUtil qw(file_exists l_abs_path);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-07-31'; # DATE
+our $DATE = '2023-08-07'; # DATE
 our $DIST = 'File-Trash-FreeDesktop'; # DIST
-our $VERSION = '0.204'; # VERSION
+our $VERSION = '0.205'; # VERSION
 
 sub new {
     require File::HomeDir::FreeDesktop;
@@ -121,12 +121,14 @@ sub list_trashes {
     my @res = map { l_abs_path($_) }
         grep {-d} (
             $self->_home_trash,
-            (map { (
-                "$_/.Trash-$>",
-                "$_/tmp/.Trash-$>",
-                "$_/.Trash/$>",
-                "$_/tmp/.Trash/$>",
+            (
+                $self->{home_only} ? () : (map { (
+                    "$_/.Trash-$>",
+                    "$_/tmp/.Trash-$>",
+                    "$_/.Trash/$>",
+                    "$_/tmp/.Trash/$>",
                 ) } @mp)
+            )
         );
 
     List::Util::uniq(@res);
@@ -387,7 +389,7 @@ File::Trash::FreeDesktop - Trash files
 
 =head1 VERSION
 
-This document describes version 0.204 of File::Trash::FreeDesktop (from Perl distribution File-Trash-FreeDesktop), released on 2023-07-31.
+This document describes version 0.205 of File::Trash::FreeDesktop (from Perl distribution File-Trash-FreeDesktop), released on 2023-08-07.
 
 =head1 SYNOPSIS
 
@@ -483,7 +485,17 @@ Weird scenario: /PATH/.Trash-UID is mounted on its own scenario? How about
 
 Constructor.
 
-Currently there are no known options.
+Known options:
+
+=over
+
+=item * home_only
+
+Bool. If set to true, instruct the module to just look for trash directory under
+the home directory and not search other filesystem mountpoints for possible
+trash directories.
+
+=back
 
 =head2 $trash->list_trashes() => LIST
 
